"""
QMVVM
===================
A Model-View-ViewModel(MVVM) framework for Qt.

Documentation is available in the docstrings and
online at https://qmvvm.org.

Examples are available at https://github.com/zhiyiYo/QMVVM/tree/master/examples.

:copyright: (c) 2025 by zhiyiYo.
:license: Apache v2.0, see LICENSE for more details.
"""

__version__ = "0.0.3"
__author__ = "zhiyiYo"

from .mvvm import QMVVM
from .ref import Ref
from .computed import Computed